from slacker import Slacker
from time import sleep


class slackmq(object):
    def __init__(self, api_token, channel, timestamp):
        self.api_token = api_token
        self.channel = channel
        self.timestamp = timestamp

    def ack(self, emoji=None):
        try:
            slack = Slacker(self.api_token)
            slack.stars.add(channel=self.channel,
                            timestamp=self.timestamp)
            if emoji is not None:
                slack.reactions.add(emoji,
                                    channel=self.channel,
                                    timestamp=self.timestamp)
            slack.pins.add(channel=self.channel,
                           timestamp=self.timestamp)
            return True
        except Exception:
            return False

    def unack(self, emoji=None):
        try:
            slack = Slacker(self.api_token)
            slack.pins.remove(channel=self.channel,
                              timestamp=self.timestamp)
            sleep(3)
            if emoji is not None:
                slack.reactions.remove(emoji,
                                       channel=self.channel,
                                       timestamp=self.timestamp)
            sleep(5)
            slack.stars.remove(channel=self.channel,
                               timestamp=self.timestamp)
        except Exception:
            return False



from os.path import join, dirname
from setuptools import setup

__version__ = open(join(dirname(__file__), 'VERSION')).read().strip()

install_requires = (
    'slacker>=0.9.50'
)

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='slackmq',
    py_modules=['slackmq'],
    version=__version__,
    description='A Slack Message Queue system',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='Dennis Mellican',
    author_email='dennis@mellican.com',
    url='https://github.com/meltaxa/slackmq',
    license='MIT',
    include_package_data=True,
    install_requires=install_requires,
    classifiers=['Development Status :: 4 - Beta',
                 'License :: OSI Approved :: MIT License',
                 'Operating System :: OS Independent',
                 'Programming Language :: Python',
                 'Programming Language :: Python :: 2',
                 'Programming Language :: Python :: 2.7',
                 'Programming Language :: Python :: 3',
                 'Programming Language :: Python :: 3.4',
                 'Programming Language :: Python :: 3.5',
                 'Programming Language :: Python :: 3.6'])
